summaryrefslogtreecommitdiffstats
path: root/remoting/host/simple_host_process.cc
diff options
context:
space:
mode:
Diffstat (limited to 'remoting/host/simple_host_process.cc')
-rw-r--r--remoting/host/simple_host_process.cc21
1 files changed, 9 insertions, 12 deletions
diff --git a/remoting/host/simple_host_process.cc b/remoting/host/simple_host_process.cc
index e3ed694..d4abc40 100644
--- a/remoting/host/simple_host_process.cc
+++ b/remoting/host/simple_host_process.cc
@@ -75,16 +75,13 @@ int main(int argc, char** argv) {
fake = true;
}
// Prompt user for username and password.
std::string username;
std::cout << "JID: ";
std::cin >> username;
- std::string password;
- SetConsoleEcho(false);
- std::cout << "Password: ";
- std::cin >> password;
- SetConsoleEcho(true);
- std::cout << std::endl;
+ std::string auth_token;
+ std::cout << "Auth Token: ";
+ std::cin >> auth_token;
scoped_ptr<remoting::Capturer> capturer;
scoped_ptr<remoting::Encoder> encoder;
@@ -106,13 +103,13 @@ int main(int argc, char** argv) {
capturer.reset(new remoting::CapturerFake());
}
// Construct a simple host with username and password.
// TODO(hclam): Allow the host to load saved credentials.
scoped_refptr<remoting::SimpleHost> host
- = new remoting::SimpleHost(username, password,
- capturer.release(),
- encoder.release(),
- executor.release());
+ = new remoting::SimpleHost(username, auth_token,
+ capturer.release(),
+ encoder.release(),
+ executor.release());
host->Run();
return 0;
}
@@ -75,16 +75,13 @@ int main(int argc, char** argv) {
fake = true;
}
- // Prompt user for username and password.
+ // Prompt user for username and auth token.
std::string username;
std::cout << "JID: ";
@@ -106,13 +103,13 @@ int main(int argc, char** argv) {
capturer.reset(new remoting::CapturerFake());
}
- // Construct a simple host with username and password.
+ // Construct a simple host with username and auth_token.
// TODO(hclam): Allow the host to load saved credentials.
scoped_refptr<remoting::SimpleHost> host